@@ -1,30 +1,30 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/18/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *   Analyze() is used to handle the "analyze" command.  this mode basically   *
+ *   Analyze() is used to handle the "analyze" command.  This mode basically   *
  *   puts Crafty into a "permanent pondering" state, where it reads a move from*
- *   the input stream, and then "ponders" for the opposite side.  whenever a   *
+ *   the input stream, and then "ponders" for the opposite side.  Whenever a   *
  *   move is entered, Crafty reads this move, updates the game board, and then *
  *   starts "pondering" for the other side.                                    *
  *                                                                             *
+ *   The purpose of this mode is to force Crafty to follow along in a game,    *
+ *   providing analysis continually for the side on move until a move is       *
+ *   entered, advancing the game to the next position.                         *
+ *                                                                             *
  *******************************************************************************
  */
 void Analyze()
 {
   int i, move, back_number, readstat = 1;
-  TREE *const tree = shared->local[0];
+  TREE *const tree = block[0];
 
 /*
  ************************************************************
  *                                                          *
- *  initialize.                                             *
+ *  Initialize.                                             *
  *                                                          *
  ************************************************************
  */
@@ -34,12 +34,12 @@ void Analyze()
   ponder_move = 0;
   analyze_mode = 1;
   if (!xboard)
-    shared->display_options |= 1 + 2 + 4;
+    display_options |= 1 + 2 + 4;
   printf("Analyze Mode: type \"exit\" to terminate.\n");
 /*
  ************************************************************
  *                                                          *
- *  now loop waiting on input, searching the current        *
+ *  Now loop waiting on input, searching the current        *
  *  position continually until a move comes in.             *
  *                                                          *
  ************************************************************
@@ -49,23 +49,23 @@ void Analyze()
       last_pv.pathd = 0;
       last_pv.pathl = 0;
       input_status = 0;
-      shared->pondering = 1;
+      pondering = 1;
       tree->position[1] = tree->position[0];
       (void) Iterate(wtm, think, 0);
-      shared->pondering = 0;
+      pondering = 0;
       if (book_move)
-        shared->moves_out_of_book = 0;
+        moves_out_of_book = 0;
       if (!xboard) {
         if (wtm)
-          printf("analyze.White(%d): ", shared->move_number);
+          printf("analyze.White(%d): ", move_number);
         else
-          printf("analyze.Black(%d): ", shared->move_number);
+          printf("analyze.Black(%d): ", move_number);
         fflush(stdout);
       }
 /*
  ************************************************************
  *                                                          *
- *  if we get back to here, something has been typed in and *
+ *  If we get back to here, something has been typed in and *
  *  is in the command buffer normally, unless the search    *
  *  terminated naturally due to finding a mate or reaching  *
  *  the max depth allowable.                                *
@@ -81,9 +81,9 @@ void Analyze()
           Print(128, "%s\n", buffer);
           if (strstr(args[0], "timeleft") && !xboard) {
             if (wtm)
-              printf("analyze.White(%d): ", shared->move_number);
+              printf("analyze.White(%d): ", move_number);
             else
-              printf("analyze.Black(%d): ", shared->move_number);
+              printf("analyze.Black(%d): ", move_number);
             fflush(stdout);
           }
         } while (strstr(args[0], "timeleft"));
@@ -111,13 +111,13 @@ void Analyze()
         for (i = 0; i < back_number; i++) {
           wtm = Flip(wtm);
           if (Flip(wtm))
-            shared->move_number--;
+            move_number--;
         }
-        if (shared->move_number == 0) {
-          shared->move_number = 1;
+        if (move_number == 0) {
+          move_number = 1;
           wtm = 1;
         }
-        sprintf(buffer, "reset %d", shared->move_number);
+        sprintf(buffer, "reset %d", move_number);
         (void) Option(tree);
         display = tree->pos;
       } else if (Option(tree)) {
@@ -126,7 +126,7 @@ void Analyze()
 /*
  ************************************************************
  *                                                          *
- *  if InputMove() can recognize this as a move, make it,   *
+ *  If InputMove() can recognize this as a move, make it,   *
  *  swap sides, and return to the top of the loop to call   *
  *  search from this new position.                          *
  *                                                          *
@@ -135,13 +135,14 @@ void Analyze()
       else if ((move = InputMove(tree, buffer, 0, wtm, 1, 0))) {
         char *outmove = OutputMove(tree, move, 0, wtm);
 
-        fseek(history_file, ((shared->move_number - 1) * 2 + 1 - wtm) * 10,
-            SEEK_SET);
-        fprintf(history_file, "%9s\n", outmove);
+        if (history_file) {
+          fseek(history_file, ((move_number - 1) * 2 + 1 - wtm) * 10, SEEK_SET);
+          fprintf(history_file, "%9s\n", outmove);
+        }
         if (wtm)
-          Print(128, "White(%d): ", shared->move_number);
+          Print(128, "White(%d): ", move_number);
         else
-          Print(128, "Black(%d): ", shared->move_number);
+          Print(128, "Black(%d): ", move_number);
         Print(128, "%s\n", outmove);
         if (speech) {
           char announce[64];
@@ -159,29 +160,16 @@ void Analyze()
 /*
  ************************************************************
  *                                                          *
- *  If Option() didn't handle the input, then it might be   *
- *  something from the DGT driver, and something from there *
- *  means to retract a move.                                *
+ *  If Option() didn't handle the input, then it is illegal *
+ *  and should be reported to the user.                     *
  *                                                          *
  ************************************************************
  */
       else {
-        if (!DGT_active) {
-          shared->pondering = 0;
-          if (Option(tree) == 0)
-            printf("illegal move: %s\n", buffer);
-          shared->pondering = 1;
-        } else {
-          wtm = Flip(wtm);
-          if (Flip(wtm))
-            shared->move_number--;
-          if (shared->move_number == 0) {
-            shared->move_number = 1;
-            wtm = 1;
-          }
-          sprintf(buffer, "reset %d", shared->move_number);
-          (void) Option(tree);
-        }
+        pondering = 0;
+        if (Option(tree) == 0)
+          printf("illegal move: %s\n", buffer);
+        pondering = 1;
         display = tree->pos;
       }
     } while (!move);
@@ -189,10 +177,10 @@ void Analyze()
       break;
     wtm = Flip(wtm);
     if (wtm)
-      shared->move_number++;
+      move_number++;
   } while (1);
   analyze_mode = 0;
   printf("analyze complete.\n");
-  shared->pondering = 0;
+  pondering = 0;
   swindle_mode = save_swindle_mode;
 }
