@@ -1,86 +1,80 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/18/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *  "annotate" command is used to search through the game in the "history" file*
- *  (often set by the "read" command which reads moves in, skipping non-move   *
- *  information such as move numbers, times, etc.)                             *
+ *  "annotate" command is used to search through the game in a pgn file, and   *
+ *  provide a qualitative analysis of each move played and then creating a new *
+ *  output file (xxx.can) containing the original game + new commentary.       *
  *                                                                             *
- *  the normal output of this command is a file, in PGN format, that contains  *
+ *  The normal output of this command is a file, in PGN format, that contains  *
  *  the moves of the game, along with analysis when Crafty does not think that *
- *  move was the best choice.  the definition of "best choice" is somewhat     *
+ *  move was the best choice.  The definition of "best choice" is somewhat     *
  *  vague, because if the move played is "close" to the best move available,   *
- *  Crafty will not comment on the move.  "close" is defined by the <margin>   *
- *  option explained below.  this basic type of annotation works by first      *
- *  using the normal tree search algorithm to find the best move.  if this     *
- *  move was the move played, no output is produced.  if a different move is   *
+ *  Crafty will not comment on the move.  "Close" is defined by the <margin>   *
+ *  option explained below.  This basic type of annotation works by first      *
+ *  using the normal tree search algorithm to find the best move.  If this     *
+ *  move was the move played, no output is produced.  If a different move is   *
  *  considered best, then the actual move played is searched to the same depth *
  *  and if the best move and actual move scores are within <margin> of each    *
  *  other, no comment is produced, otherwise crafty inserts the evaluation for *
  *  the move played, followed by the eval and PV for the best continuation it  *
- *  found.  you can enter suggested moves for Crafty to analyze at any point   *
+ *  found.  You can enter suggested moves for Crafty to analyze at any point   *
  *  by simply entering a move as an analysis-type comment using (move) or      *
  *  {move}.  Crafty will search that move in addition to the move actually     *
  *  played and the move it thinks is best.                                     *
  *                                                                             *
- *  the format of the command is as follows:                                   *
+ *  The format of the command is as follows:                                   *
  *                                                                             *
- *      annotate filename b*w*bw*name moves margin time [n]                    *
+ *      annotate filename b|w|bw|name moves margin time [n]                    *
  *                                                                             *
- *  filename is the input file where Crafty will obtain the moves to annotate, *
+ *  Filename is the input file where Crafty will obtain the moves to annotate, *
  *  and output will be written to file "filename.can".                         *
  *                                                                             *
- *      annotateh filename b*w*bw*name moves margin time [n]                   *
+ *      annotateh filename b|w|bw|name moves margin time [n]                   *
  *                                                                             *
- *  can be used to produce an HTML-compatible file that includes bitmapped     *
- *  diagrams of the positions where Crafty provides analysis.  this file can be*
+ *  Can be used to produce an HTML-compatible file that includes bitmapped     *
+ *  diagrams of the positions where Crafty provides analysis.  This file can be*
  *  opened by a browser to provide much easier 'reading'.                      *
  *                                                                             *
- *      annotatet filename b*w*bw*name moves margin time [n]                   *
+ *      annotatet filename b|w|bw|name moves margin time [n]                   *
  *                                                                             *
- *  can be used to produce a LaTeX-compatible file that includes LaTeX chess   *
- *  fonts.  this file can be read/printed by any program that can handle LaTeX *
+ *  Can be used to produce a LaTeX-compatible file that includes LaTeX chess   *
+ *  fonts.  This file can be read/printed by any program that can handle LaTeX *
  *  input.                                                                     *
  *                                                                             *
- *  where b/w/bw indicates whether to annotate only the white side (w), the    *
- *  black side (b) or both (bw).  you can also specify a name (or part of a    *
+ *  Where b/w/bw indicates whether to annotate only the white side (w), the    *
+ *  black side (b) or both (bw).  You can also specify a name (or part of a    *
  *  name, just be sure it is unique in the name tags for clarity in who you    *
  *  mean).                                                                     *
  *                                                                             *
- *  moves indicates the move or moves to annotate.  it can be a single move,   *
+ *  Moves indicates the move or moves to annotate.  It can be a single move,   *
  *  which indicates the starting move number to annotate, or it can be a range,*
  *  which indicates a range of move (1-999 gets the whole game.)               *
  *                                                                             *
- *  margin is the difference between Crafty's evaluation for the move actually *
+ *  Margin is the difference between Crafty's evaluation for the move actually *
  *  played and for the move Crafty thinks is best, before crafty will generate *
  *  a comment in the annotation file.  1.0 is a pawn, and will only generate   *
  *  comments if the move played is 1.000 (1 pawn) worse than the best move     *
  *  found by doing a complete search.                                          *
  *                                                                             *
- *  time is time per move to search, in seconds.                               *
+ *  Time is time per move to search, in seconds.                               *
  *                                                                             *
  *  [n] is optional and tells Crafty to produce the PV/score for the "n" best  *
  *  moves.  Crafty stops when the best move reaches the move played in the game*
- *  or after displaying n moves, whichever comes first.  if you use -n, then it*
+ *  or after displaying n moves, whichever comes first.  If you use -n, then it*
  *  will display n moves regardless of where the game move ranks.              *
  *                                                                             *
  *******************************************************************************
  */
-
 #define MIN_DECISIVE_ADV 150
 #define MIN_MODERATE_ADV  70
 #define MIN_SLIGHT_ADV    30
-
 void Annotate()
 {
   FILE *annotate_in, *annotate_out;
-  char text[128], tbuffer[512], colors[32] = { "" }, pname[128] = {
+  char text[128], tbuffer[4096], colors[32] = { "" }, pname[128] = {
   ""};
   int annotate_margin, annotate_score[100], player_score, best_moves,
       annotate_wtm;
@@ -90,7 +84,7 @@ void Annotate()
   int searches_done, read_status;
   PATH temp[100], player_pv;
   int temp_search_depth;
-  TREE *const tree = shared->local[0];
+  TREE *const tree = block[0];
   char html_br[5] = { "" };
   int save_swindle_mode;
   int html_mode = 0;
@@ -99,8 +93,8 @@ void Annotate()
 /*
  ************************************************************
  *                                                          *
- *   first, quiz the user for the options needed to         *
- *   successfully annotate a game.                          *
+ *   First, extract the options from the command line to    *
+ *   determine what the user wanted us to do.               *
  *                                                          *
  ************************************************************
  */
@@ -156,7 +150,7 @@ void Annotate()
     line2 = 999;
   }
   annotate_margin = atof(args[4]) * pawn_value;
-  annotate_search_time_limit = atoi(args[5]) * 100;
+  annotate_search_time_limit = atof(args[5]) * 100;
   if (nargs > 6)
     best_moves = atoi(args[6]);
   else
@@ -164,10 +158,10 @@ void Annotate()
 /*
  ************************************************************
  *                                                          *
- *   reset the game to "square 0" to start the annotation   *
- *   procedure.  then we read moves from the input file,    *
+ *   Reset the game to "square 0" to start the annotation   *
+ *   procedure.  Then we read moves from the input file,    *
  *   make them on the game board, and annotate if the move  *
- *   is for the correct side.  if we haven't yet reached    *
+ *   is for the correct side.  If we haven't yet reached    *
  *   the starting move to annotate, we skip the Search()    *
  *   stuff and read another move.                           *
  *                                                          *
@@ -179,6 +173,7 @@ void Annotate()
   temp_search_depth = search_depth;
   read_status = ReadPGN(0, 0);
   read_status = ReadPGN(annotate_in, 0);
+  player_pv.path[1] = 0;
   while (read_status != -1) {
     ponder_move = 0;
     last_pv.pathd = 0;
@@ -188,14 +183,14 @@ void Annotate()
     tree->pv[0].pathl = 0;
     tree->pv[0].pathd = 0;
     analysis_printed = 0;
-    InitializeChessBoard(&tree->position[0]);
+    InitializeChessBoard(tree);
     tree->position[1] = tree->position[0];
     wtm = 1;
-    shared->move_number = 1;
+    move_number = 1;
 /*
  ************************************************************
  *                                                          *
- *   now grab the PGN tag values so they can be copied to   *
+ *   Now grab the PGN tag values so they can be copied to   *
  *   the .can file for reference.                           *
  *                                                          *
  ************************************************************
@@ -270,47 +265,48 @@ void Annotate()
       if (move <= 0)
         break;
       strcpy(text, OutputMove(tree, move, 0, wtm));
-      fseek(history_file, ((shared->move_number - 1) * 2 + 1 - wtm) * 10,
-          SEEK_SET);
-      fprintf(history_file, "%9s\n", text);
+      if (history_file) {
+        fseek(history_file, ((move_number - 1) * 2 + 1 - wtm) * 10, SEEK_SET);
+        fprintf(history_file, "%9s\n", text);
+      }
       if (wtm)
-        Print(4095, "White(%d): %s\n", shared->move_number, text);
+        Print(4095, "White(%d): %s\n", move_number, text);
       else
-        Print(4095, "Black(%d): %s\n", shared->move_number, text);
+        Print(4095, "Black(%d): %s\n", move_number, text);
       if (analysis_printed)
-        fprintf(annotate_out, "%3d.%s%8s\n", shared->move_number,
+        fprintf(annotate_out, "%3d.%s%8s\n", move_number,
             (wtm ? "" : "     ..."), text);
       else {
         if (wtm)
-          fprintf(annotate_out, "%3d.%8s", shared->move_number, text);
+          fprintf(annotate_out, "%3d.%8s", move_number, text);
         else
           fprintf(annotate_out, "%8s\n", text);
       }
       analysis_printed = 0;
-      if (shared->move_number >= line1 && shared->move_number <= line2) {
+      if (move_number >= line1 && move_number <= line2) {
         if (annotate_wtm == 2 || annotate_wtm == wtm) {
           last_pv.pathd = 0;
           last_pv.pathl = 0;
-          shared->thinking = 1;
+          thinking = 1;
           RootMoveList(wtm);
 /*
  ************************************************************
  *                                                          *
- *   now search the position to see if the move played is   *
- *   the best move possible.  if not, then search just the  *
- *   move played to get a score for it as well, so we can   *
+ *   Search the position to see if the move played is the   *
+ *   best move possible.  If not, then search just the move *
+ *   played to get a score for it as well, so we can        *
  *   determine if annotated output is appropriate.          *
  *                                                          *
  ************************************************************
  */
-          shared->search_time_limit = annotate_search_time_limit;
+          search_time_limit = annotate_search_time_limit;
           search_depth = temp_search_depth;
           player_score = -999999;
           search_player = 1;
           for (searches_done = 0; searches_done < abs(best_moves);
               searches_done++) {
             if (searches_done > 0) {
-              shared->search_time_limit = 3 * annotate_search_time_limit;
+              search_time_limit = 3 * annotate_search_time_limit;
               search_depth = temp[0].pathd;
             }
             Print(4095, "\n              Searching all legal moves.");
@@ -324,19 +320,19 @@ void Annotate()
               search_player = 0;
             }
             temp[searches_done] = tree->pv[0];
-            for (i = 0; i < shared->n_root_moves; i++) {
-              if (shared->root_moves[i].move == tree->pv[0].path[1]) {
-                for (; i < shared->n_root_moves; i++)
-                  shared->root_moves[i] = shared->root_moves[i + 1];
-                shared->n_root_moves--;
+            for (i = 0; i < n_root_moves; i++) {
+              if (root_moves[i].move == tree->pv[0].path[1]) {
+                for (; i < n_root_moves; i++)
+                  root_moves[i] = root_moves[i + 1];
+                n_root_moves--;
                 break;
               }
             }
-            if (shared->n_root_moves == 0 || (annotate_margin >= 0 &&
+            if (n_root_moves == 0 || (annotate_margin >= 0 &&
                     player_score + annotate_margin >
                     annotate_score[searches_done]
                     && best_moves > 0)) {
-              if (shared->n_root_moves == 0)
+              if (n_root_moves == 0)
                 searches_done++;
               break;
             }
@@ -347,31 +343,31 @@ void Annotate()
             Print(4095, "--------------------\n");
             tree->position[1] = tree->position[0];
             search_move = move;
-            shared->root_moves[0].move = move;
-            shared->root_moves[0].nodes = 0;
-            shared->root_moves[0].status = 0;
-            shared->n_root_moves = 1;
-            shared->search_time_limit = 3 * annotate_search_time_limit;
+            root_moves[0].move = move;
+            root_moves[0].nodes = 0;
+            root_moves[0].status = 0;
+            n_root_moves = 1;
+            search_time_limit = 3 * annotate_search_time_limit;
             search_depth = temp[0].pathd;
             if (search_depth == temp_search_depth)
-              shared->search_time_limit = annotate_search_time_limit;
+              search_time_limit = annotate_search_time_limit;
             InitializeHashTables();
             player_score = Iterate(wtm, annotate, 1);
             player_pv = tree->pv[0];
             search_depth = temp_search_depth;
-            shared->search_time_limit = annotate_search_time_limit;
+            search_time_limit = annotate_search_time_limit;
             search_move = 0;
           }
 /*
  ************************************************************
  *                                                          *
- *   output the score/pv for the move played unless it      *
- *   matches what Crafty would have played.  if it doesn't  *
+ *   Output the score/pv for the move played unless it      *
+ *   matches what Crafty would have played.  If it doesn't  *
  *   then output the pv for what Crafty thinks is best.     *
  *                                                          *
  ************************************************************
  */
-          shared->thinking = 0;
+          thinking = 0;
           if (player_pv.pathd > 1 && player_pv.pathl >= 1 &&
               player_score + annotate_margin < annotate_score[0] &&
               (temp[0].path[1] != player_pv.path[1] || annotate_margin < 0.0 ||
@@ -430,9 +426,9 @@ void Annotate()
 /*
  ************************************************************
  *                                                          *
- *   before going on to the next move, see if the user has  *
+ *   Before going on to the next move, see if the user has  *
  *   included a set of other moves that require a search.   *
- *   if so, search them one at a time and produce the ana-  *
+ *   If so, search them one at a time and produce the ana-  *
  *   lysis for each one.                                    *
  *                                                          *
  ************************************************************
@@ -441,19 +437,19 @@ void Annotate()
       while (read_status == 2) {
         suggested = InputMove(tree, buffer, 0, wtm, 1, 0);
         if (suggested > 0) {
-          shared->thinking = 1;
+          thinking = 1;
           Print(4095, "\n              Searching only the move suggested.");
           Print(4095, "--------------------\n");
           tree->position[1] = tree->position[0];
           search_move = suggested;
-          shared->search_time_limit = 3 * annotate_search_time_limit;
+          search_time_limit = 3 * annotate_search_time_limit;
           search_depth = temp[0].pathd;
           InitializeHashTables();
           annotate_score[0] = Iterate(wtm, annotate, 0);
           search_depth = temp_search_depth;
-          shared->search_time_limit = annotate_search_time_limit;
+          search_time_limit = annotate_search_time_limit;
           search_move = 0;
-          shared->thinking = 0;
+          thinking = 0;
           twtm = wtm;
           path_len = tree->pv[0].pathl;
           if (tree->pv[0].pathd > 1 && path_len >= 1) {
@@ -487,7 +483,7 @@ void Annotate()
       MakeMoveRoot(tree, move, wtm);
       wtm = Flip(wtm);
       if (wtm)
-        shared->move_number++;
+        move_number++;
       if (read_status != 0)
         break;
       if (line2 < -1)
@@ -524,11 +520,17 @@ void Annotate()
     fclose(annotate_out);
   if (annotate_in)
     fclose(annotate_in);
-  shared->search_time_limit = 0;
+  search_time_limit = 0;
   annotate_mode = 0;
   swindle_mode = save_swindle_mode;
 }
-
+/*
+ *******************************************************************************
+ *                                                                             *
+ *   These functions provide HTML output support interfaces.                   *
+ *                                                                             *
+ *******************************************************************************
+ */
 void AnnotateHeaderHTML(char *title_text, FILE * annotate_out)
 {
   fprintf(annotate_out,
@@ -549,13 +551,10 @@ void AnnotateFooterHTML(FILE * annotate_out)
   fprintf(annotate_out, "</BODY>\n");
   fprintf(annotate_out, "</HTML>\n");
 }
-
 void AnnotatePositionHTML(TREE * RESTRICT tree, int wtm, FILE * annotate_out)
 {
   char filename[32], html_piece;
   char alt[32];
-  char xlate[15] =
-      { 'q', 'r', 'b', 0, 'k', 'n', 'p', 0, 'P', 'N', 'K', 0, 'B', 'R', 'Q' };
   int rank, file;
 
 /*  Display the board in HTML using table of images.          */
@@ -569,7 +568,7 @@ void AnnotatePositionHTML(TREE * RESTRICT tree, int wtm, FILE * annotate_out)
         (void) strcat(filename, "w");
       else
         (void) strcat(filename, "b");
-      html_piece = xlate[PcOnSq((rank << 3) + file) + 7];
+      html_piece = translate[PcOnSq((rank << 3) + file) + 6];
       switch (html_piece) {
       case 'p':
         strcat(filename, "bp");
@@ -643,7 +642,6 @@ void AnnotatePositionHTML(TREE * RESTRICT tree, int wtm, FILE * annotate_out)
  * Author         : Alexander Wagner                                           *
  *                                      University of Michigan                 *
  * Date           : 03.01.04                                                   *
- * Report bugs to :                                                            *
  *                                                                             *
  * Last Modified  : 03.01.04                                                   *
  *                                                                             *
@@ -690,12 +688,9 @@ void AnnotateFooterTeX(FILE * annotate_out)
 {
   fprintf(annotate_out, "\n\n\\end{document}\n");
 }
-
 void AnnotatePositionTeX(TREE * tree, int wtm, FILE * annotate_out)
 {
   char filename[32], html_piece;
-  char xlate[15] =
-      { 'q', 'r', 'b', 0, 'k', 'n', 'p', 0, 'P', 'N', 'K', 0, 'B', 'R', 'Q' };
   int rank, file;
 
 /*  Display the board in LaTeX using picture notation, similar to html */
@@ -707,7 +702,7 @@ void AnnotatePositionTeX(TREE * tree, int wtm, FILE * annotate_out)
         (void) strcpy(filename, " ");
       else
         (void) strcpy(filename, "*");
-      html_piece = xlate[PcOnSq((rank << 3) + file) + 7];
+      html_piece = translate[PcOnSq((rank << 3) + file) + 6];
       switch (html_piece) {
       case 'p':
         strcpy(filename, "p");
@@ -761,7 +756,6 @@ void AnnotatePositionTeX(TREE * tree, int wtm, FILE * annotate_out)
   fprintf(annotate_out, "}\n \\end{nochess}\\end{center} \n\n");
   fprintf(annotate_out, "\n");
 }
-
 char *AnnotateVtoNAG(int value, int wtm, int html_mode, int latex)
 {
   static char buf[64];
