@@ -1,17 +1,14 @@
-#include <stdio.h>
-#include <stdlib.h>
 #include "chess.h"
 #include "data.h"
-
 /* last modified 06/05/98 */
 /*
  *******************************************************************************
  *                                                                             *
  *   Drawn() is used to answer the question "is this position a hopeless draw?"*
- *   several considerations are included in making this decision, but the most *
- *   basic one is simple the remaining material for each side.  if either side *
- *   has pawns, it's not a draw.  with no pawns, equal material is a draw.     *
- *   otherwise, the superior side must have enough material to be able to force*
+ *   Several considerations are included in making this decision, but the most *
+ *   basic one is simply the remaining material for each side.  If either side *
+ *   has pawns, it's not a draw.  With no pawns, equal material is a draw.     *
+ *   Otherwise, the superior side must have enough material to be able to force*
  *   a mate.                                                                   *
  *                                                                             *
  *******************************************************************************
@@ -21,17 +18,17 @@ int Drawn(TREE * RESTRICT tree, int value)
 /*
  ************************************************************
  *                                                          *
- *   if either side has pawns, the game is not a draw for   *
+ *   If either side has pawns, the game is not a draw for   *
  *   lack of material.                                      *
  *                                                          *
  ************************************************************
  */
-  if (TotalWhitePawns || TotalBlackPawns)
+  if (TotalPieces(white, pawn) || TotalPieces(black, pawn))
     return (0);
 /*
  ************************************************************
  *                                                          *
- *   the search result must indicate a draw also, otherwise *
+ *   The search result must indicate a draw also, otherwise *
  *   it could be a tactical win or loss.                    *
  *                                                          *
  ************************************************************
@@ -41,31 +38,31 @@ int Drawn(TREE * RESTRICT tree, int value)
 /*
  ************************************************************
  *                                                          *
- *   if neither side has pawns, and one side has some sort  *
+ *   If neither side has pawns, and one side has some sort  *
  *   of material superiority, then determine if the winning *
  *   side has enough material to win.                       *
  *                                                          *
  ************************************************************
  */
-  if (TotalWhitePieces < 5 && TotalBlackPieces < 5)
+  if (TotalPieces(white, occupied) < 5 && TotalPieces(black, occupied) < 5)
     return (2);
-  if (TotalWhitePieces == 5 || TotalWhitePieces > 6)
+  if (TotalPieces(white, occupied) == 5 || TotalPieces(white, occupied) > 6)
     return (0);
-  if (TotalBlackPieces == 5 || TotalBlackPieces > 6)
+  if (TotalPieces(black, occupied) == 5 || TotalPieces(black, occupied) > 6)
     return (0);
-  if ((TotalWhitePieces == 6 && !WhiteBishops && Material > 0) ||
-      (TotalBlackPieces == 6 && !BlackBishops && Material < 0))
+  if ((TotalPieces(white, occupied) == 6 && !Bishops(white) && Material > 0) ||
+      (TotalPieces(black, occupied) == 6 && !Bishops(black) && Material < 0))
     return (2);
 /*
  ************************************************************
  *                                                          *
- *   if neither side has pawns, then one side must have     *
+ *   If neither side has pawns, then one side must have     *
  *   some sort of material superiority, otherwise it is a   *
  *   draw.                                                  *
  *                                                          *
  ************************************************************
  */
-  if (TotalWhitePieces == TotalBlackPieces)
+  if (TotalPieces(white, occupied) == TotalPieces(black, occupied))
     return (1);
   return (0);
 }
