@@ -1,31 +1,28 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/18/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *   Edit() is used to edit (alter) the current board position.  it clears the *
- *   board and then allows the operator to enter a position using one of four  *
+ *   Edit() is used to edit (alter) the current board position.  It clears the *
+ *   board and then allows the operator to enter a position using the syntax   *
+ *   defined by the xboard/winboard "edit" command.                            *
  *                                                                             *
- *   white sets the color of pieces added to white.  this color will stay in   *
+ *   White sets the color of pieces added to white.  This color will stay in   *
  *   effect until specifically changed.                                        *
  *                                                                             *
- *   black sets the color of pieces added to black.  this color will stay in   *
+ *   Black sets the color of pieces added to black.  This color will stay in   *
  *   effect until specifically changed.                                        *
  *                                                                             *
  *   # clears the chessboard completely.                                       *
  *                                                                             *
- *   c changes (toggles) the color of pieces being placed on the board.        *
+ *   C changes (toggles) the color of pieces being placed on the board.        *
  *                                                                             *
- *   end (or . for ICS/Xboard) terminates Edit().                              *
+ *   End (or . for ICS/Xboard) terminates Edit().                              *
  *                                                                             *
- *   pieces are placed on the board by three character "commands" of the form  *
+ *   Pieces are placed on the board by three character "commands" of the form  *
  *   [piece][square] where piece is a member of the normal set of pieces       *
- *   {P,N,B,R,Q,K} and [square] is algebraic square notation (a1-h8).  ex: Ke8 *
+ *   {P,N,B,R,Q,K} and [square] is algebraic square notation (a1-h8).  Ex: Ke8 *
  *   puts a king (of the current "color") on square e8.                        *
  *                                                                             *
  *******************************************************************************
@@ -34,16 +31,16 @@ void Edit(void)
 {
   int athome = 1, i, piece, readstat, square, tfile, trank, wtm = 1, error = 0;
   static const char pieces[] =
-      { 'x', 'X', 'P', 'p', 'N', 'n', 'K', 'k', '*', '*',
-    'B', 'b', 'R', 'r', 'Q', 'q', '\0'
+      { 'x', 'X', 'P', 'p', 'N', 'n', 'B', 'b', 'R', 'r',
+    'Q', 'q', 'K', 'k', '\0'
   };
-  TREE *const tree = shared->local[0];
+  TREE *const tree = block[0];
 
 /*
  ************************************************************
  *                                                          *
- *   next, process the commands to set the board[n] form    *
- *   of the chess position.                                 *
+ *   Process the commands to set the board[n] form of the   *
+ *   chess position.                                        *
  *                                                          *
  ************************************************************
  */
@@ -61,7 +58,6 @@ void Edit(void)
     nargs = ReadParse(buffer, args, " 	;");
     if (xboard)
       Print(128, "edit.command:%s\n", args[0]);
-
     if (!strcmp(args[0], "white"))
       wtm = 1;
     else if (!strcmp(args[0], "black"))
@@ -102,20 +98,22 @@ void Edit(void)
     } else
       printf("unrecognized piece %s\n", args[0]);
   }
-
 /*
  ************************************************************
  *                                                          *
- *   now, if a king is on its original square, check the    *
+ *   Now, if a king is on its original square, check the    *
  *   rooks to see if they are and set the castle status     *
- *   accordingly.  note that this checks for pieces on the  *
+ *   accordingly.  Note that this checks for pieces on the  *
  *   original rank, but not their original squares (ICS     *
  *   "wild" games) and doesn't set castling if true.        *
  *                                                          *
+ *   The winboard/xboard "edit" command does not give us a  *
+ *   way of setting castling status, so we have to guess.   *
+ *                                                          *
  ************************************************************
  */
-  WhiteCastle(0) = 0;
-  BlackCastle(0) = 0;
+  Castle(0, white) = 0;
+  Castle(0, black) = 0;
   EnPassant(0) = 0;
   for (i = 0; i < 16; i++)
     if (PcOnSq(i) == 0 || PcOnSq(i + 48) == 0)
@@ -129,38 +127,38 @@ void Edit(void)
           PcOnSq(H8) == -rook)) {
     if (PcOnSq(E1) == king) {
       if (PcOnSq(A1) == rook)
-        WhiteCastle(0) = WhiteCastle(0) | 2;
+        Castle(0, white) = Castle(0, white) | 2;
       if (PcOnSq(H1) == rook)
-        WhiteCastle(0) = WhiteCastle(0) | 1;
+        Castle(0, white) = Castle(0, white) | 1;
     }
     if (PcOnSq(E8) == -king) {
       if (PcOnSq(A8) == -rook)
-        BlackCastle(0) = BlackCastle(0) | 2;
+        Castle(0, black) = Castle(0, black) | 2;
       if (PcOnSq(H8) == -rook)
-        BlackCastle(0) = BlackCastle(0) | 1;
+        Castle(0, black) = Castle(0, black) | 1;
     }
   }
 /*
  ************************************************************
  *                                                          *
- *   basic board is now set.  now it's time to set the bit  *
+ *   Basic board is now set.  Now it's time to set the bit  *
  *   board representation correctly.                        *
  *                                                          *
  ************************************************************
  */
-  SetChessBitBoards(&tree->position[0]);
+  SetChessBitBoards(tree);
   error += InvalidPosition(tree);
   if (!error) {
     if (log_file)
       DisplayChessBoard(log_file, tree->pos);
     wtm = 1;
-    shared->move_number = 1;
-    tree->rep_game = 0;
-    tree->rep_list[tree->rep_game] = HashKey;
+    move_number = 1;
+    tree->rep_index[white] = 0;
+    tree->rep_index[black] = 0;
     tree->position[0].rule_50_moves = 0;
-    shared->moves_out_of_book = 0;
+    moves_out_of_book = 0;
   } else {
-    InitializeChessBoard(&tree->position[0]);
+    InitializeChessBoard(tree);
     Print(4095, "Illegal position, using normal initial chess position\n");
   }
 }
