@@ -1,10 +1,6 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/18/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -12,30 +8,41 @@
  *   measure its performance on a particular machine, or to evaluate its skill *
  *   after modifying it in some way.                                           *
  *                                                                             *
- *   the test is initiated by using the "evtest <filename>" command to read in *
- *   the suite of problems from file <filename>.  the format of this file is   *
+ *   The test is initiated by using the "evtest <filename>" command to read in *
+ *   the suite of problems from file <filename>.  The format of this file is   *
  *   as follows:                                                               *
  *                                                                             *
- *   setboard <forsythe-string>:  this sets the board position using the usual *
- *   forsythe notation (see module SetBoard() in setc for a full explanation   *
- *   planation of the syntax).                                                 *
+ *   <forsythe-string>  This sets the board position using the usual Forsythe  *
+ *   notation (see module SetBoard() for a full explanation explanation of the *
+ *   syntax).                                                                  *
  *                                                                             *
- *   after reading this position, the program then calls Evaluate() to produce *
+ *   After reading this position, the program then calls Evaluate() to produce *
  *   a positional evaluation, along with any debug output from Evaluate(), and *
  *   then goes on to the next position.                                        *
  *                                                                             *
+ *   A common use (with code included below) is to take a position, and then   *
+ *   "flip" it (reverse the board rank by rank changing the color of each      *
+ *   piece as this is done, giving us two positions.  We then take each of     *
+ *   these and mirror them, which reverses them file by file, which now gives  *
+ *   four positions in total.  We run these thru Evaluate() to make sure that  *
+ *   all produce exactly the same score, except for the color change for the   *
+ *   two that changed the piece colors.  This is used to make certain that the *
+ *   evaluation is not asymmetric with respect to the colors, or to the side   *
+ *   of the board, which catches errors that are difficult to spot otherwise.  *
+ *                                                                             *
  *******************************************************************************
  */
 void EVTest(char *filename)
 {
   FILE *test_input;
   char *eof;
-  TREE *const tree = shared->local[0];
+  char buff[4096];
+  TREE *const tree = block[0];
 
 /*
  ************************************************************
  *                                                          *
- *   read in the position and then the solutions.  then do  *
+ *   Read in the position and then the solutions.  Then do  *
  *   a call to Evaluate() which will normally display the   *
  *   debugging stuff that is enabled.                       *
  *                                                          *
@@ -46,7 +53,7 @@ void EVTest(char *filename)
     return;
   }
   while (1) {
-    eof = fgets(buffer, 512, test_input);
+    eof = fgets(buffer, 4096, test_input);
     if (eof) {
       char *delim;
 
@@ -58,58 +65,71 @@ void EVTest(char *filename)
         *delim = ' ';
     } else
       break;
+    strcpy(buff, buffer);
     nargs = ReadParse(buffer, args, " ;");
     if (!strcmp(args[0], "end"))
       break;
+/*
+ ************************************************************
+ *                                                          *
+ *   Now for the asymmetry tests.  We use the built-in      *
+ *   commands "flip" and "flop" to create the four          *
+ *   positions, and call Evaluate() for each.               *
+ *                                                          *
+ ************************************************************
+ */
     else {
       int s1, s2, s3, s4, id;
-      char buff[256];
 
       for (id = 2; id < nargs; id++)
         if (!strcmp(args[id], "id"))
           break;
       if (id >= nargs)
         id = 0;
-      SetBoard(&tree->position[0], nargs, args, 0);
-      strcpy(buff, args[0]);
-
-      WhiteCastle(0) = 0;
-      WhiteCastle(1) = 0;
-      BlackCastle(0) = 0;
-      BlackCastle(1) = 0;
-      shared->root_wtm = wtm;
+      SetBoard(tree, nargs, args, 0);
+      Castle(0, white) = 0;
+      Castle(1, white) = 0;
+      Castle(0, black) = 0;
+      Castle(1, black) = 0;
+      root_wtm = wtm;
       PreEvaluate(tree);
       tree->pawn_score.key = 0;
       s1 = Evaluate(tree, 0, wtm, -99999, 99999);
-
       strcpy(buffer, "flop");
       (void) Option(tree);
       PreEvaluate(tree);
       tree->pawn_score.key = 0;
       s2 = Evaluate(tree, 0, wtm, -99999, 99999);
-
       strcpy(buffer, "flip");
       (void) Option(tree);
       PreEvaluate(tree);
       tree->pawn_score.key = 0;
       s3 = Evaluate(tree, 0, wtm, -99999, 99999);
-
       strcpy(buffer, "flop");
       (void) Option(tree);
       PreEvaluate(tree);
       tree->pawn_score.key = 0;
       s4 = Evaluate(tree, 0, wtm, -99999, 99999);
-
-      if (s1 != s2 || s1 != s3 || s1 != s4 || s2 != s3 || s2 != s4 ||
-          s3 != s4) {
+/*
+ ************************************************************
+ *                                                          *
+ *   If the evaluations (with sign corrected if piece color *
+ *   was changed) are different, we display the four values *
+ *   and then display the original board position so that   *
+ *   we can debug the cause of the asymmetry.               *
+ *                                                          *
+ ************************************************************
+ */
+      if (s1 != s2 || s1 != s3 || s1 != s4 ||
+          s2 != s3 || s2 != s4 || s3 != s4) {
         strcpy(buffer, "flip");
         (void) Option(tree);
         printf("FEN = %s\n", buff);
         DisplayChessBoard(stdout, tree->pos);
         if (id)
           Print(4095, "id=%s  ", args[id + 1]);
-        Print(4095, "wtm=%d  score=%d  %d (flop)  %d (flip)  %d (flop)\n", wtm, s1, s2, s3,
-            s4);
+        Print(4095, "wtm=%d  score=%d  %d (flop)  %d (flip)  %d (flop)\n", wtm,
+            s1, s2, s3, s4);
       }
     }
   }
