@@ -1,22 +1,31 @@
 #if !defined(NOEGTB)
-#  include <stdio.h>
 #  include "chess.h"
 #  include "data.h"
-
-/* last modified 11/03/98 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
  *  EGTBProbe() is the interface to the new tablebase code by Eugene Nalimov.  *
- *  this is called from Search() when 5 or fewer pieces are left on the board. *
+ *  This is called from Search() after a capture, when the number of pieces    *
+ *  remaining on the board is less than or equal to the max number of pieces   *
+ *  we have in the EGTB files that are available for use.                      *
  *                                                                             *
  *******************************************************************************
  */
-
+#  define  VInitSqCtr(rgCtr, rgSquares, piece, bitboard) {       \
+  int  cPieces=0;                                                \
+  BITBOARD bbTemp=(bitboard);                                    \
+  while (bbTemp) {                                               \
+    const squaret sq=MSB(bbTemp);                                \
+    (rgSquares)[(piece)*C_PIECES+cPieces]=sq;                    \
+    cPieces++;                                                   \
+    Clear(sq, bbTemp);                                           \
+  }                                                              \
+  (rgCtr)[(piece)]=cPieces;                                      \
+}
 #  define  T_INDEX64
 #  define  XX  127
 #  define  C_PIECES  3  /* Maximum # of pieces of one color OTB */
-
 #  if defined (T_INDEX64) && defined (_MSC_VER)
 typedef unsigned __int64 INDEX;
 #  elif defined (T_INDEX64)
@@ -24,24 +33,20 @@ typedef unsigned long long INDEX;
 #  else
 typedef unsigned long INDEX;
 #  endif
-
 typedef unsigned int squaret;
 
 /* Those declarations necessary because Crafty is C, not C++ program */
-
 #  if defined (_MSC_VER)
 #    define  TB_FASTCALL  __fastcall
 #  else
 #    define  TB_FASTCALL
 #  endif
-
-typedef int color;
+typedef int pcolor;
 
 #  define  x_colorWhite  0
 #  define  x_colorBlack  1
 #  define  x_colorNeutral  2
 #  define COLOR_DECLARED
-
 typedef int piece;
 
 #  define  x_pieceNone    0
@@ -63,22 +68,19 @@ typedef signed char tb_t;
 #  define bev_limax   (-1)      /* mated in max moves */
 #  define bev_li0     (-tbbe_ssL)
                                 /* mated in 0 moves */
-
 typedef INDEX(TB_FASTCALL * PfnCalcIndex)
  (squaret *, squaret *, squaret, int fInverse);
-
 extern int IDescFindFromCounters(int *);
-extern int FRegisteredFun(int, color);
-extern PfnCalcIndex PfnIndCalcFun(int, color);
-extern int TB_FASTCALL L_TbtProbeTable(int, color, INDEX);
+extern int FRegisteredFun(int, pcolor);
+extern PfnCalcIndex PfnIndCalcFun(int, pcolor);
+extern int TB_FASTCALL L_TbtProbeTable(int, pcolor, INDEX);
 
 #  define PfnIndCalc PfnIndCalcFun
 #  define FRegistered FRegisteredFun
-
 int EGTBProbe(TREE * RESTRICT tree, int ply, int wtm, int *score)
 {
   int rgiCounters[10], iTb, fInvert;
-  color side;
+  pcolor side;
   squaret rgsqWhite[C_PIECES * 5 + 1], rgsqBlack[C_PIECES * 5 + 1];
   squaret *psqW, *psqB, sqEnP;
   INDEX ind;
@@ -87,25 +89,25 @@ int EGTBProbe(TREE * RESTRICT tree, int ply, int wtm, int *score)
 /*
  ************************************************************
  *                                                          *
- *   initialize counters and piece arrays so the probe code *
+ *   Initialize counters and piece arrays so the probe code *
  *   can compute the modified Godel number.                 *
  *                                                          *
  ************************************************************
  */
-  VInitSqCtr(rgiCounters, rgsqWhite, 0, WhitePawns);
-  VInitSqCtr(rgiCounters, rgsqWhite, 1, WhiteKnights);
-  VInitSqCtr(rgiCounters, rgsqWhite, 2, WhiteBishops);
-  VInitSqCtr(rgiCounters, rgsqWhite, 3, WhiteRooks);
-  VInitSqCtr(rgiCounters, rgsqWhite, 4, WhiteQueens);
-  VInitSqCtr(rgiCounters + 5, rgsqBlack, 0, BlackPawns);
-  VInitSqCtr(rgiCounters + 5, rgsqBlack, 1, BlackKnights);
-  VInitSqCtr(rgiCounters + 5, rgsqBlack, 2, BlackBishops);
-  VInitSqCtr(rgiCounters + 5, rgsqBlack, 3, BlackRooks);
-  VInitSqCtr(rgiCounters + 5, rgsqBlack, 4, BlackQueens);
+  VInitSqCtr(rgiCounters, rgsqWhite, 0, Pawns(white));
+  VInitSqCtr(rgiCounters, rgsqWhite, 1, Knights(white));
+  VInitSqCtr(rgiCounters, rgsqWhite, 2, Bishops(white));
+  VInitSqCtr(rgiCounters, rgsqWhite, 3, Rooks(white));
+  VInitSqCtr(rgiCounters, rgsqWhite, 4, Queens(white));
+  VInitSqCtr(rgiCounters + 5, rgsqBlack, 0, Pawns(black));
+  VInitSqCtr(rgiCounters + 5, rgsqBlack, 1, Knights(black));
+  VInitSqCtr(rgiCounters + 5, rgsqBlack, 2, Bishops(black));
+  VInitSqCtr(rgiCounters + 5, rgsqBlack, 3, Rooks(black));
+  VInitSqCtr(rgiCounters + 5, rgsqBlack, 4, Queens(black));
 /*
  ************************************************************
  *                                                          *
- *   quick early exit.  is the tablebase for the current    *
+ *   Quick early exit.  Is the tablebase for the current    *
  *   set of pieces registered?                              *
  *                                                          *
  ************************************************************
@@ -116,14 +118,14 @@ int EGTBProbe(TREE * RESTRICT tree, int ply, int wtm, int *score)
 /*
  ************************************************************
  *                                                          *
- *   yes, finish setting up to probe the tablebase.  if     *
+ *   Yes, finish setting up to probe the tablebase.  If     *
  *   black is the "winning" side (more pieces) then we need *
  *   to "invert" the pieces in the lists.                   *
  *                                                          *
  ************************************************************
  */
-  rgsqWhite[C_PIECES * 5] = WhiteKingSQ;
-  rgsqBlack[C_PIECES * 5] = BlackKingSQ;
+  rgsqWhite[C_PIECES * 5] = KingSQ(white);
+  rgsqBlack[C_PIECES * 5] = KingSQ(black);
   if (iTb > 0) {
     side = wtm ? x_colorWhite : x_colorBlack;
     fInvert = 0;
@@ -139,7 +141,7 @@ int EGTBProbe(TREE * RESTRICT tree, int ply, int wtm, int *score)
 /*
  ************************************************************
  *                                                          *
- *   now check to see if this particular tablebase for this *
+ *   Now check to see if this particular tablebase for this *
  *   color to move is registered.                           *
  *                                                          *
  ************************************************************
@@ -154,7 +156,7 @@ int EGTBProbe(TREE * RESTRICT tree, int ply, int wtm, int *score)
 /*
  ************************************************************
  *                                                          *
- *   now convert to correct MATE range to match the value   *
+ *   Convert to correct MATE range to match the value       *
  *   Crafty uses.                                           *
  *                                                          *
  ************************************************************
