@@ -1,38 +1,38 @@
-#include <stdio.h>
-#include <stdlib.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 01/23/03 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *   RepetitionCheck() is used to detect a draw by repetition.  it saves the   *
- *   current position in the repetition list each time it is called.  the list *
- *   contains all positions encountered since the last irreversible move       *
- *   (capture or pawn push).                                                   *
+ *   RepetitionCheck() is used to detect a draw by repetition.  The repetition *
+ *   list is a 2d array indexed by wtm (0,1) and the repetition indices which  *
+ *   are also indexed by wtm.  This keeps positions with wtm separate from the *
+ *   positions where it is btm, so that we can easily check the positions for  *
+ *   the right side on move without having to wade through the positions with  *
+ *   the wrong side on move as well.  Positions are only added to this list in *
+ *   MakeMove() which alsi increments the proper index.  UnmakeMove() then     *
+ *   decrements the proper index when the move is retracted, effectively       *
+ *   removing the position from the list.                                      *
  *                                                                             *
- *   RepetitionCheck() then scans the list to determine if this position has   *
- *   occurred before.  if so, the position will be treated as a draw by        *
- *   Search().   note that for a repetition to happen in the first two plies   *
- *   of the tree, the position has to be repeated three times, while for plies *
- *   beyond two, two repetitions trigger a draw score.                         *
+ *   RepetitionCheck() scans the list to determine if this position has        *
+ *   occurred before.  If so, the position will be treated as a draw by        *
+ *   Search().                                                                 *
  *                                                                             *
- *   RepetitionCheck() also handles 50-move draws.  the position[] structure   *
- *   countains the count of moves since the last capture or pawn push.  when   *
+ *   RepetitionCheck() also handles 50-move draws.  The position[] structure   *
+ *   countains the count of moves since the last capture or pawn push.  When   *
  *   this value reaches 100 (plies, which is 50 moves) the score is set to     *
  *   DRAW.                                                                     *
  *                                                                             *
  *******************************************************************************
  */
-int RepetitionCheck(TREE * RESTRICT tree, int ply)
+int RepetitionCheck(TREE * RESTRICT tree, int ply, int wtm)
 {
-  register int where, thispos;
+  register int where, loops;
 
 /*
  ************************************************************
  *                                                          *
- *   if the 50-move rule has been reached, then adjust the  *
+ *   If the 50-move rule has been reached, then adjust the  *
  *   score to reflect the impending draw.                   *
  *                                                          *
  ************************************************************
@@ -42,35 +42,26 @@ int RepetitionCheck(TREE * RESTRICT tree, int ply)
 /*
  ************************************************************
  *                                                          *
- *   insert the board into the next slot in the repetition  *
- *   list.  then scan the list.  we look for the case where *
- *   the position has been seen one time before, unless we  *
- *   are at ply 1 or 2, where we must have seen the same    *
- *   position twice prior to this.                          *
+ *   Now we scan the right part of the repetition list, and *
+ *   stop when we reach the current repetition index value  *
+ *   since positions beyond that index are not valid.  We   *
+ *   only need to search backward thru the list using the   *
+ *   50-move rule counter as a limit since repetitions can  *
+ *   not occur across an irreversible move.                 *
  *                                                          *
  ************************************************************
  */
-  thispos = tree->rep_game + ply - 1;
-  tree->rep_list[thispos] = HashKey;
-  if (ply > 3) {
-    int limit = thispos - Rule50Moves(ply);
-
-    for (where = thispos - 2; where >= limit; where -= 2)
-      if (HashKey == tree->rep_list[where])
-        return (1);
-  } else {
-    int count = 0;
-
-    for (where = thispos - 2; where >= 0; where -= 2)
-      if (HashKey == tree->rep_list[where])
-        count++;
-    if (count > 1)
+  loops = (Rule50Moves(ply) + 1) >> 1;
+  for (where = tree->rep_index[wtm] - 1; where >= 0; where--) {
+    if (loops-- <= 0)
+      break;
+    if (HashKey == tree->rep_list[wtm][where])
       return (1);
   }
   return (0);
 }
 
-/* last modified 01/23/03 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -80,14 +71,14 @@ int RepetitionCheck(TREE * RESTRICT tree, int ply)
  *                                                                             *
  *******************************************************************************
  */
-int RepetitionCheckBook(TREE * RESTRICT tree, int ply)
+int RepetitionCheckBook(TREE * RESTRICT tree, int ply, int wtm)
 {
-  register int where, thispos;
+  register int where;
 
 /*
  ************************************************************
  *                                                          *
- *   if the 50-move rule has been reached, then adjust the  *
+ *   If the 50-move rule has been reached, then adjust the  *
  *   score to reflect the impending draw.                   *
  *                                                          *
  ************************************************************
@@ -97,30 +88,30 @@ int RepetitionCheckBook(TREE * RESTRICT tree, int ply)
 /*
  ************************************************************
  *                                                          *
- *   scan the list.  we look for the case where the         *
+ *   Scan the list.  We look for the case where the         *
  *   position has been seen one time before.                *
  *                                                          *
  ************************************************************
  */
-  thispos = tree->rep_game + ply - 1;
-  for (where = thispos - 2; where >= 0; where -= 2)
-    if (HashKey == tree->rep_list[where])
+  for (where = 0; where < tree->rep_index[wtm]; where++)
+    if (HashKey == tree->rep_list[wtm][where])
       return (1);
   return (0);
 }
 
-/* last modified 02/15/05 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *   RepetitionDraw() is used to detect a draw by repetition.  this routine is *
+ *   RepetitionDraw() is used to detect a draw by repetition.  This routine is *
  *   only called from Main() and simply scans the complete list searching for  *
  *   exactly three repetitions (two additional repetitions of the current      *
- *   position.)                                                                *
+ *   position.)  This is used to actually claim a draw by repetition or by the *
+ *   50 move rule.                                                             *
  *                                                                             *
  *******************************************************************************
  */
-int RepetitionDraw(TREE * RESTRICT tree, int ply)
+int RepetitionDraw(TREE * RESTRICT tree, int ply, int wtm)
 {
   register int reps;
   int where;
@@ -128,7 +119,7 @@ int RepetitionDraw(TREE * RESTRICT tree, int ply)
 /*
  ************************************************************
  *                                                          *
- *   if the 50-move rule has been reached, then adjust the  *
+ *   If the 50-move rule has been reached, then adjust the  *
  *   score to reflect the impending draw.                   *
  *                                                          *
  ************************************************************
@@ -138,14 +129,14 @@ int RepetitionDraw(TREE * RESTRICT tree, int ply)
 /*
  ************************************************************
  *                                                          *
- *   scan the repetition list to determine if this position *
+ *   Scan the repetition list to determine if this position *
  *   has occurred before.                                   *
  *                                                          *
  ************************************************************
  */
   reps = 0;
-  for (where = tree->rep_game; where >= 0; where -= 2)
-    if (HashKey == tree->rep_list[where])
+  for (where = 0; where < tree->rep_index[wtm]; where++)
+    if (HashKey == tree->rep_list[wtm][where])
       reps++;
-  return (reps == 3);
+  return (reps == 2);
 }
