@@ -1,27 +1,32 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
- *   SetBoard() is used to set up the board in any position desired.  it uses  *
+ *   SetBoard() is used to set up the board in any position desired.  It uses  *
  *   a forsythe-like string of characters to describe the board position.      *
  *                                                                             *
- *   the standard piece codes p,n,b,r,q,k are used to denote the type of piece *
+ *   The standard piece codes p,n,b,r,q,k are used to denote the type of piece *
  *   on a square, upper/lower case are used to indicate the side (program/opp.)*
  *   of the piece.                                                             *
  *                                                                             *
- *   the pieces are entered with the rank on the program's side of the board   *
- *   entered first, and the rank on the opponent's side entered last.  to enter*
- *   empty squares, use a number between 1 and 8 to indicate how many adjacent *
- *   squares are empty.  use a / to terminate each rank after all of the pieces*
- *   for that rank have been entered.                                          *
+ *   The pieces are entered with square a8 first, then b8, ... until the full  *
+ *   8th rank is completed.  A "/" terminates that rank.  This is repeated for *
+ *   each of the 8 ranks, with the last (1st) rank not needing a terminating   *
+ *   "/".  For empty squares, a number between 1 and 8 can be used to indicate *
+ *   the number of adjacent empty squares.                                     *
  *                                                                             *
- *   the following input will setup the board position that given below:       *
+ *   That board description must be followed by a "b" or "w" to indicate which *
+ *   side is on move.                                                          *
+ *                                                                             *
+ *   Next, up to 4 characters are used to indicate which side can castle and   *
+ *   to which side.  An uppercase K means white can castle kingside, while a   *
+ *   lowercase q means black can castle queenside.                             *
+ *                                                                             *
+ *   Finally, if there is an enpassant capture possible (the last move was a   *
+ *   double pawn move and there was an enemy pawn that could capture it.  The  *
+ *   square is the square the capturing pawn ends up on.                       *
  *                                                                             *
  *         K2R/PPP////q/5ppp/7k/ b - -                                         *
  *                                                                             *
@@ -37,22 +42,16 @@
  *                          *  *  *  *  * -p -p -p                             *
  *                          *  *  *  *  *  *  * -k                             *
  *                                                                             *
- *   the field after the final "/" should be either b or w to indicate which   *
- *   side is "on move."  after this side-to-move field any of the following    *
- *   characters can appear to indicate the following:  KQ: white can castle    *
- *   kingside/queenside/both;  kq: same for black;  a1-h8: indicates the       *
- *   square occupied by a pawn that can be captured en passant.                *
- *                                                                             *
  *******************************************************************************
  */
-void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
+void SetBoard(TREE * tree, int nargs, char *args[], int special)
 {
   int twtm, i, match, num, pos, square, tboard[64];
   int bcastle, ep, wcastle, error = 0;
   char input[80];
   static const char bdinfo[] =
-      { 'q', 'r', 'b', '*', 'k', 'n', 'p', '*', 'P', 'N',
-    'K', '*', 'B', 'R', 'Q', '*', '1', '2', '3', '4',
+      { 'k', 'q', 'r', 'b', 'n', 'p', '*', 'P', 'N', 'B',
+    'R', 'Q', 'K', '*', '1', '2', '3', '4',
     '5', '6', '7', '8', '/'
   };
   static const char status[13] =
@@ -61,8 +60,6 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
   };
   int whichsq;
   static const int firstsq[8] = { 56, 48, 40, 32, 24, 16, 8, 0 };
-  TREE *const tree = shared->local[0];
-
   if (special)
     strcpy(input, initial_position);
   else
@@ -72,7 +69,7 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
 /*
  ************************************************************
  *                                                          *
- *   scan the input string searching for pieces, numbers    *
+ *   Scan the input string searching for pieces, numbers    *
  *   [empty squares], slashes [end-of-rank] and a blank     *
  *   [end of board, start of castle status].                *
  *                                                          *
@@ -82,13 +79,13 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
   square = firstsq[whichsq];
   num = 0;
   for (pos = 0; pos < (int) strlen(args[0]); pos++) {
-    for (match = 0; match < 25 && args[0][pos] != bdinfo[match]; match++);
-    if (match > 24)
+    for (match = 0; match < 23 && args[0][pos] != bdinfo[match]; match++);
+    if (match > 22)
       break;
 /*
  "/" -> end of this rank.
  */
-    else if (match == 24) {
+    else if (match == 22) {
       num = 0;
       if (whichsq > 6)
         break;
@@ -97,12 +94,13 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
 /*
  "1-8" -> empty squares.
  */
-    else if (match >= 16) {
-      num += match - 15;
-      square += match - 15;
+    else if (match >= 14) {
+      num += match - 13;
+      square += match - 13;
       if (num > 8) {
         printf("more than 8 squares on one rank\n");
-        return;
+        error = 1;
+        break;
       }
       continue;
     }
@@ -112,15 +110,16 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
     else {
       if (++num > 8) {
         printf("more than 8 squares on one rank\n");
-        return;
+        error = 1;
+        break;
       }
-      tboard[square++] = match - 7;
+      tboard[square++] = match - 6;
     }
   }
 /*
  ************************************************************
  *                                                          *
- *   now extract (a) side to move [w/b], (b) castle status  *
+ *   Now extract (a) side to move [w/b], (b) castle status  *
  *   [KkQq for white/black king-side ok, white/black queen- *
  *   side ok], (c) enpassant target square.                 *
  *                                                          *
@@ -133,7 +132,7 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
 /*
  ************************************************************
  *                                                          *
- *   side to move.                                          *
+ *   Side to move.                                          *
  *                                                          *
  ************************************************************
  */
@@ -148,7 +147,7 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
 /*
  ************************************************************
  *                                                          *
- *   castling/enpassant status.                             *
+ *   Castling/enpassant status.                             *
  *                                                          *
  ************************************************************
  */
@@ -185,9 +184,9 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
   }
   for (i = 0; i < 64; i++)
     PcOnSq(i) = tboard[i];
-  position->w_castle = wcastle;
-  position->b_castle = bcastle;
-  position->enpassant_target = 0;
+  Castle(0, white) = wcastle;
+  Castle(0, black) = bcastle;
+  EnPassant(0) = 0;
   if (ep) {
     if (Rank(ep) == RANK6) {
       if (PcOnSq(ep - 8) != -pawn)
@@ -202,47 +201,45 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
       ep = 0;
       error = 1;
     }
-    position->enpassant_target = ep;
+    EnPassant(0) = ep;
   }
-  position->rule_50_moves = 0;
+  Rule50Moves(0) = 0;
 /*
  ************************************************************
  *                                                          *
- *   now check the castling status and enpassant status to  *
+ *   Now check the castling status and enpassant status to  *
  *   make sure that the board is in a state that matches    *
  *   these.                                                 *
  *                                                          *
  ************************************************************
  */
-  if (((position->w_castle & 2) && (PcOnSq(A1) != rook)) ||
-      ((position->w_castle & 1) && (PcOnSq(H1) != rook)) ||
-      ((position->b_castle & 2) && (PcOnSq(A8) != -rook)) ||
-      ((position->b_castle & 1) && (PcOnSq(H8) != -rook))) {
+  if (((Castle(0, white) & 2) && (PcOnSq(A1) != rook)) ||
+      ((Castle(0, white) & 1) && (PcOnSq(H1) != rook)) ||
+      ((Castle(0, black) & 2) && (PcOnSq(A8) != -rook)) ||
+      ((Castle(0, black) & 1) && (PcOnSq(H8) != -rook))) {
     printf("ERROR-- castling status does not match board position\n");
     error = 1;
   }
 /*
  ************************************************************
  *                                                          *
- *   now set the bitboards so that error tests can be done. *
+ *   Now set the bitboards so that error tests can be done. *
  *                                                          *
  ************************************************************
  */
-  if ((twtm && position->enpassant_target &&
-          (PcOnSq(position->enpassant_target + 8) != -pawn) &&
-          (PcOnSq(position->enpassant_target - 7) != pawn) &&
-          (PcOnSq(position->enpassant_target - 9) != pawn)) || (Flip(twtm) &&
-          position->enpassant_target &&
-          (PcOnSq(position->enpassant_target - 8) != pawn) &&
-          (PcOnSq(position->enpassant_target + 7) != -pawn) &&
-          (PcOnSq(position->enpassant_target + 9) != -pawn))) {
-    position->enpassant_target = 0;
+  if ((twtm && EnPassant(0) && (PcOnSq(EnPassant(0) + 8) != -pawn) &&
+          (PcOnSq(EnPassant(0) - 7) != pawn) &&
+          (PcOnSq(EnPassant(0) - 9) != pawn)) || (Flip(twtm) && EnPassant(0) &&
+          (PcOnSq(EnPassant(0) - 8) != pawn) &&
+          (PcOnSq(EnPassant(0) + 7) != -pawn) &&
+          (PcOnSq(EnPassant(0) + 9) != -pawn))) {
+    EnPassant(0) = 0;
   }
-  SetChessBitBoards(position);
+  SetChessBitBoards(tree);
 /*
  ************************************************************
  *                                                          *
- *   now check the position for a sane position, which      *
+ *   Now check the position for a sane position, which      *
  *   means no more than 8 pawns, no more than 10 knights,   *
  *   bishops or rooks, no more than 9 queens, no pawns on   *
  *   1st or 8th rank, etc.                                  *
@@ -254,28 +251,24 @@ void SetBoard(SEARCH_POSITION * position, int nargs, char *args[], int special)
   if (!error) {
     if (log_file)
       DisplayChessBoard(log_file, tree->pos);
-    tree->rep_game = 0;
-    tree->rep_list[tree->rep_game] = HashKey;
-    position->rule_50_moves = 0;
+    tree->rep_index[white] = 0;
+    tree->rep_index[black] = 0;
+    Rule50Moves(0) = 0;
     if (!special) {
       last_mate_score = 0;
-      for (i = 0; i < 8192; i++) {
-        shared->history[i] = 0;
-        shared->history_fh[i] = 0;
-        shared->history_count[i] = 1;
-      }
-      for (i = 0; i < MAXPLY; i++) {
-        tree->killers[i].move1 = 0;
-        tree->killers[i].move2 = 0;
-      }
+      InitializeKillers();
       last_pv.pathd = 0;
       last_pv.pathl = 0;
       tree->pv[0].pathd = 0;
       tree->pv[0].pathl = 0;
-      shared->moves_out_of_book = 0;
+      moves_out_of_book = 0;
     }
   } else {
-    InitializeChessBoard(&tree->position[0]);
+    if (special)
+      Print(4095, "bad string = \"%s\"\n", initial_position);
+    else
+      Print(4095, "bad string = \"%s\"\n", args[0]);
+    InitializeChessBoard(tree);
     Print(4095, "Illegal position, using normal initial chess position\n");
   }
 }
